==> react-native-hotqa-sdk-0.1.1.tgz: package/src/components/single-choice/index.js <==
import React, {useState, useRef} from 'react';
import {
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
  Dimensions,
  FlatList,
} from 'react-native';
import AntDesign from 'react-native-vector-icons/AntDesign';
import {color_blue, color_orange} from '../../assets/colors';
import {arrSTT} from '../../common/constant';
import SharePreference from '../../common/SharePreference';
AntDesign.loadFont();
import Sound from 'react-native-sound';
import ic_play from '../../assets/images/ic_play.png';
import ic_pause from '../../assets/images/ic_pause.png';
import Player from '../../components/player';

export default (props) => {
  const {
    onPress,
    user_answer,
    data,
    item_question,
    keyPage,
    index,
    isFinish,
  } = props;
  // console.log('SINGLE_CHOICE', data);

  // const [isPlay, setPlay] = useState(false);
  // const player = useRef(null);

  data.map((item) => {
    user_answer.forEach((answer) => {
      if (answer.question_id === item_question.id) {
        if (item.value === answer.user_answer.value) {
          item.selected = true;
        } else {
          item.selected = false;
        }
      }
    });
    return item;
  });

  // let sound = null;
  // if (keyPage === index) {
  //   const extra = JSON.parse(item_question.extra);
  //   extra.forEach((item) => {
  //     if (item.type === 'audio') {
  //       player.current?.playSound(item.value);
  //     }
  //   });
  // }

  const renderItem = ({item, index}) => {
    return (
      <View style={styles.container}>
        <TouchableOpacity
          disabled={isFinish}
          onPress={() => onPress(item)}
          style={styles.configView}>
          <Text style={[styles.txtABC, item.selected && styles.selected]}>
            {arrSTT[index]}
          </Text>
          <Text style={[styles.text]}>{item.data.value}</Text>
        </TouchableOpacity>
        {isFinish && item.correct === 1 && (
          <AntDesign
            name="checkcircle"
            style={{fontSize: 30, marginLeft: 20, color: 'green'}}
          />
        )}
        {isFinish && item.correct === 0 && (
          <AntDesign
            name="closecircleo"
            style={{fontSize: 30, marginLeft: 20, color: 'red'}}
          />
        )}
      </View>
    );
  };

  return (
    <View>
      <FlatList
        data={data}
        renderItem={renderItem}
        keyExtractor={(item, index) => index.toString()}
      />
      {/* <Player
        keyPage={keyPage}
        index={index}
        item={item_question}
        ref={player}
      /> */}
    </View>
  );
};
const width = Dimensions.get('screen').width * 0.6;

const styles = StyleSheet.create({
  container: {
    width: width,
    flexDirection: 'row',
    alignItems: 'center',
  },
  configView: {
    flex: 0.7,
    flexDirection: 'row',
    marginVertical: '1%',
    padding: 10,
    marginEnd: 20,
    alignItems: 'center',
  },

  image: {
    height: 100,
  },
  text: {
    fontSize: 18,
    marginStart: 20,
  },
  txtABC: {
    fontSize: 22,
    fontWeight: 'bold',
    backgroundColor: color_orange,
    color: color_blue,
    paddingVertical: 8,
    paddingHorizontal: 13,
    textAlign: 'center',
    borderRadius: 10,
    overflow: 'hidden',
  },
  selected: {
    backgroundColor: color_blue,
    color: '#FFF',
  },
});

==> react-native-hotqa-sdk-0.1.3.tgz: package/src/components/single-choice/index.js <==
import React, {useState, useRef} from 'react';
import {
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
  Dimensions,
  FlatList,
} from 'react-native';
import AntDesign from 'react-native-vector-icons/AntDesign';
import {color_blue, color_orange} from '../../assets/colors';
import {arrSTT} from '../../common/constant';
import SharePreference from '../../common/SharePreference';
AntDesign.loadFont();
import Sound from 'react-native-sound';
import ic_play from '../../assets/images/ic_play.png';
import ic_pause from '../../assets/images/ic_pause.png';
import Player from '../../components/player';

export default (props) => {
  const {
    onPress,
    user_answer,
    data,
    item_question,
    keyPage,
    index,
    isFinish,
  } = props;
  // console.log('SINGLE_CHOICE', user_answer);

  // const [isPlay, setPlay] = useState(false);
  // const player = useRef(null);
  data.map((item) => {
    if (user_answer.length === 0) {
      item.selected = false;
    } else {
      user_answer.forEach((answer) => {
        if (answer.question_id === item_question.id) {
          if (item.value === answer.user_answer.value) {
            item.selected = true;
          } else {
            item.selected = false;
          }
        }
      });
    }
    return item;
  });

  // let sound = null;
  // if (keyPage === index) {
  //   const extra = JSON.parse(item_question.extra);
  //   extra.forEach((item) => {
  //     if (item.type === 'audio') {
  //       player.current?.playSound(item.value);
  //     }
  //   });
  // }

  const renderItem = ({item, index}) => {
    return (
      <View style={styles.container}>
        <TouchableOpacity
          disabled={isFinish}
          onPress={() => onPress(item)}
          style={styles.configView}>
          <Text style={[styles.txtABC, item.selected && styles.selected]}>
            {arrSTT[index]}
          </Text>
          <Text style={[styles.text]}>{item.data.value}</Text>
        </TouchableOpacity>
        {isFinish && item.correct === 1 && (
          <AntDesign
            name="checkcircle"
            style={{fontSize: 30, marginLeft: 20, color: 'green'}}
          />
        )}
        {isFinish && item.correct === 0 && (
          <AntDesign
            name="closecircleo"
            style={{fontSize: 30, marginLeft: 20, color: 'red'}}
          />
        )}
      </View>
    );
  };

  return (
    <View>
      <FlatList
        data={data}
        renderItem={renderItem}
        keyExtractor={(item, index) => index.toString()}
      />
      {/* <Player
        keyPage={keyPage}
        index={index}
        item={item_question}
        ref={player}
      /> */}
    </View>
  );
};
const width = Dimensions.get('screen').width * 0.6;

const styles = StyleSheet.create({
  container: {
    width: width,
    flexDirection: 'row',
    alignItems: 'center',
  },
  configView: {
    flex: 0.7,
    flexDirection: 'row',
    marginVertical: '1%',
    padding: 10,
    marginEnd: 20,
    alignItems: 'center',
  },

  image: {
    height: 100,
  },
  text: {
    fontSize: 18,
    marginStart: 20,
  },
  txtABC: {
    fontSize: 22,
    fontWeight: 'bold',
    backgroundColor: color_orange,
    color: color_blue,
    paddingVertical: 8,
    paddingHorizontal: 13,
    textAlign: 'center',
    borderRadius: 10,
    overflow: 'hidden',
  },
  selected: {
    backgroundColor: color_blue,
    color: '#FFF',
  },
});
